@@ -1,6 +1,32 @@
 
 
-from jgtutils.jgtconstants import ( AO,MFI_SIGNAL,AC,JAW,TEETH,LIPS,BJAW,BLIPS,BTEETH,TLIPS,TTEETH,TJAW,HIGH,LOW,CLOSE,OPEN,ASKCLOSE,ASKHIGH,ASKLOW,BIDCLOSE,BIDHIGH,BIDLOW,MFI)
+from jgtutils.jgtconstants import (
+    AO,
+    MFI_SIGNAL,
+    AC,
+    JAW,
+    TEETH,
+    LIPS,
+    BJAW,
+    BLIPS,
+    BTEETH,
+    TLIPS,
+    TTEETH,
+    TJAW,
+    HIGH,
+    LOW,
+    CLOSE,
+    OPEN,
+    ASKCLOSE,
+    ASKHIGH,
+    ASKLOW,
+    BIDCLOSE,
+    BIDHIGH,
+    BIDLOW,
+    MFI,
+    MFI_VAL,
+    ZCOL,
+)
 
 from jgtutils.jgtconstants import ZONE_SIGNAL as ZONE_DEFAULT_COLNAME
 from jgtutils.jgtconstants import MFI_SIGNAL as MFI_DEFAULT_COLNAME
@@ -85,4 +111,34 @@ PATTERN_NS = "pn"
 
 
 
-CONVERTION_EXCLUDED_COLUMNS=[AO,AC,JAW,TEETH,LIPS,BJAW,BLIPS,BTEETH,TLIPS,TTEETH,TJAW,HIGH,LOW,CLOSE,OPEN,ASKCLOSE,ASKHIGH,ASKLOW,BIDCLOSE,BIDHIGH,BIDLOW,MFI]
\ No newline at end of file
+CONVERTION_EXCLUDED_COLUMNS=[
+    AO,
+    AC,
+    JAW,
+    TEETH,
+    LIPS,
+    BJAW,
+    BLIPS,
+    BTEETH,
+    TLIPS,
+    TTEETH,
+    TJAW,
+    HIGH,
+    LOW,
+    CLOSE,
+    OPEN,
+    ASKCLOSE,
+    ASKHIGH,
+    ASKLOW,
+    BIDCLOSE,
+    BIDHIGH,
+    BIDLOW,
+    MFI,
+    MFI_VAL,
+    "mfi_str",
+    "mfi_str_M1",
+    "mfi_str_W1",
+    ZCOL,
+    "zcol_M1",
+    "zcol_W1",
+]
